@@ -19,13 +19,21 @@
 
 
 check_census_api_call <- function(call){
+
   if(class(call) != "response"){
     stop("A valid response was not returned")
   }
-  httr::content(call, as = "text", encoding = "UTF-8") %>%
-    xml2::as_xml_document() %>%
-    xml2::xml_find_all("body") %>%
-    xml2::xml_text() %>%
-    gsub(pattern = "\\s{2}", replacement = "") %>%
-    gsub(pattern = "^\\s", replacement = "")
+
+  returned_call <- httr::content(call, as = "text", encoding = "UTF-8")
+
+  if( show_condition(xml2::as_xml_document(returned_call)["node"]) !="error"){
+    returned_call %>%
+      xml2::as_xml_document()%>%
+      xml2::xml_find_all("body") %>%
+      xml2::xml_text() %>%
+      gsub(pattern = "\\s{2}", replacement = "") %>%
+      gsub(pattern = "^\\s", replacement = "")
+  } else{
+    stop(paste0("\nThe following is a message from the US Census API:\n",returned_call ))
+  }
 }
